@@ -1,8 +1,9 @@
-#' Find the operating system
+#' Find the operating system or architecture.
 #'
 #' Indicate whether we are on Windows or MacOSX.
+#' For MacOSX, we can also determine if we are on an x86-64 or Arm-based architecture.
 #'
-#' @return Logical scalar indicating whether we are on the specified OS.
+#' @return Logical scalar indicating whether we are on the specified OS and/or architecture.
 #'
 #' @author Aaron Lun
 #'
@@ -19,3 +20,9 @@ isWindows <- function() {
 isMacOSX <- function() {
     Sys.info()[["sysname"]] == "Darwin"
 }
+
+#' @export
+#' @rdname isWindows
+isMacOSXArm <- function() {
+    grepl("^arm", Sys.info()[["machine"]])
+}
